; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| AI Commands |-------------------------------------------------------
[Command]
name = "AI SWITCH 01"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 02"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 03"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 04"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 05"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 06"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 07"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 08"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 09"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 10"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 11"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 12"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 13"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 14"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 15"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 16"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 17"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 18"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 19"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 20"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 21"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 22"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 23"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 24"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 25"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 26"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 27"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 28"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 29"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 30"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 31"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 32"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 33"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 34"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 35"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 36"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 37"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 38"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 39"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 40"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 41"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 42"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 43"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 44"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 45"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 46"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 47"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 48"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 49"
command = U, U, U
time = 0

[Command]
name = "AI SWITCH 50"
command = U, U, U
time = 0

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

[Command]
name = "TripleKFPalm"   ;Same name as above
command = ~D, DF, F, D, DF, F, y
time = 20

[Command]
name = "SmashKFUpper"
command = ~D, DB, B, D, DB, B, x;~F, D, DF, F, D, DF, x
time = 20

[Command]
name = "SmashKFUpper"   ;Same name as above
command = ~D, DB, B, D, DB, B, y;~F, D, DF, F, D, DF, y
time = 20

[Command]
name = "Super Combination"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
name = "Falling Stars"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "Stars Burst"
command = ~D, DF, F, D, DF, F, c
time = 20

[Command]
name = "Super Fire"
command = ~D, DB, B, D, DB, B, a
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

[Command]
name = "Star Canon"
command = ~D, DF, F, a

[Command]
name = "Star Bomb"
command = ~D, DF, F, b

[Command]
name = "Warp"
command = a+b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

[State -2]
type = varset
trigger1 = 1
var(20) = 1

[State -2]
type = varset
trigger1 = command = "AI SWITCH 01"
trigger2 = command = "AI SWITCH 02"
trigger3 = command = "AI SWITCH 03"
trigger4 = command = "AI SWITCH 04"
trigger5 = command = "AI SWITCH 05"
trigger6 = command = "AI SWITCH 06"
trigger7 = command = "AI SWITCH 07"
trigger8 = command = "AI SWITCH 08"
trigger9 = command = "AI SWITCH 09"
trigger10 = command = "AI SWITCH 10"
trigger11 = command = "AI SWITCH 11"
trigger12 = command = "AI SWITCH 12"
trigger13 = command = "AI SWITCH 13"
trigger14 = command = "AI SWITCH 14"
trigger15 = command = "AI SWITCH 15"
trigger16 = command = "AI SWITCH 16"
trigger17 = command = "AI SWITCH 17"
trigger18 = command = "AI SWITCH 18"
trigger19 = command = "AI SWITCH 19"
trigger20 = command = "AI SWITCH 20"
trigger21 = command = "AI SWITCH 21"
trigger22 = command = "AI SWITCH 22"
trigger23 = command = "AI SWITCH 23"
trigger24 = command = "AI SWITCH 24"
trigger25 = command = "AI SWITCH 25"
trigger26 = command = "AI SWITCH 26"
trigger27 = command = "AI SWITCH 27"
trigger28 = command = "AI SWITCH 28"
trigger29 = command = "AI SWITCH 29"
trigger30 = command = "AI SWITCH 30"
trigger31 = command = "AI SWITCH 31"
trigger32 = command = "AI SWITCH 32"
trigger33 = command = "AI SWITCH 33"
trigger34 = command = "AI SWITCH 34"
trigger35 = command = "AI SWITCH 35"
trigger36 = command = "AI SWITCH 36"
trigger37 = command = "AI SWITCH 37"
trigger38 = command = "AI SWITCH 38"
trigger39 = command = "AI SWITCH 39"
trigger40 = command = "AI SWITCH 40"
trigger41 = command = "AI SWITCH 41"
trigger42 = command = "AI SWITCH 42"
trigger43 = command = "AI SWITCH 43"
trigger44 = command = "AI SWITCH 44"
trigger45 = command = "AI SWITCH 45"
trigger46 = command = "AI SWITCH 46"
trigger47 = command = "AI SWITCH 47"
trigger48 = command = "AI SWITCH 48"
trigger49 = command = "AI SWITCH 49"
trigger50 = command = "AI SWITCH 50"
trigger51 = palno = 12
var(21) = var(20)

;===========================================================================
;-| AI Motions |--------------------------------------------------------

[State -1, Unknown2]
type = ChangeState
value = 10011
triggerall = var(21) >= 1
triggerall = power >= 3000
triggerall = statetype != A
triggerall = ctrl
triggerall = time > 0
trigger1 = enemy,pos X > -30
trigger1 = enemy,pos X < 30
trigger1 = enemy,pos Y > -60

[State -1, Unknown4]
type = ChangeState
value = 2+(random > 800)*10009
triggerall = var(21) >= 1
triggerall = power >= 4000
triggerall = statetype != A
triggerall = ctrl
triggerall = time > 0
trigger1 = enemy,stateno < 120
trigger2 = enemy,stateno > 155

[State -1, Warp]
type = ChangeState
value = 60000
triggerall = var(21) >= 1
triggerall = time > 0
triggerall = movetype = H
trigger1 = palno = 6
trigger2 = palno = 12

[State -1, Unknown3]
type = ChangeState
value = 10021
triggerall = var(21) >= 1
triggerall = power >= 2000
triggerall = time > 0
trigger1 = P2bodydist X > 100
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Unknown2]
type = ChangeState
value = 440
triggerall = var(21) >= 1
triggerall = statetype != A
triggerall = ctrl
triggerall = time > 0
trigger1 = moveguarded

[State -1, Unknown2]
type = ChangeState
value = 1000
triggerall = var(21) >= 1
triggerall = statetype != A
triggerall = ctrl
triggerall = time > 0
trigger1 = P2bodydist X <= 70
trigger1 = P2bodydist X > 40
trigger1 = enemynear,vel X > 0

[State -1, Unknown2]
type = ChangeState
value = 1110
triggerall = var(21) >= 1
triggerall = statetype != A
triggerall = ctrl
triggerall = time > 0
trigger1 = P2bodydist X < 40
trigger1 = enemynear,vel X > 0

[State -1, Unknown2]
type = ChangeState
value = 1050
triggerall = var(21) >= 1
triggerall = statetype != A
triggerall = ctrl
triggerall = time > 0
trigger1 = Prevstateno = 1110

[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = var(21) >= 1
triggerall = statetype = A
triggerall = ctrl
triggerall = time > 0
trigger1 = P2bodydist X <= 20

[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = var(21) >= 1
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
triggerall = time > 0
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = var(21) >= 1
triggerall = power >= 1000
triggerall = p2movetype = H
triggerall = enemynear,pos Y > -60
triggerall = enemynear,vel Y > -6
triggerall = P2bodydist X <= 50
triggerall = time > 0
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact

[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = var(21) >= 1
triggerall = power >= 1000
triggerall = statetype != A
triggerall = P2statetype = S
triggerall = P2bodydist X <= 20
triggerall = enemynear,pos Y > -150
triggerall = enemynear,vel Y > -3
triggerall = time > 0
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact
trigger2 = AnimElem = 14

[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = var(21) >= 1
triggerall = power >= 1000
triggerall = statetype != A
triggerall = P2statetype = A
triggerall = P2movetype = H
triggerall = P2bodydist X <= 20
triggerall = enemynear,pos Y > -150
triggerall = time > 0
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact

[State -1, Unknown2]
type = ChangeState
value = 60011
triggerall = var(21) >= 1
triggerall = statetype != A
triggerall = ctrl
triggerall = time > 0
trigger1 = numhelper(2) <= 0

[State -1, Unknown2]
type = ChangeState
value = 60021
triggerall = time > 0
trigger1 = var(21) >= 1
trigger1 = statetype != A
trigger1 = ctrl
trigger1 = P2bodydist X > 100
trigger1 = numhelper(3) <= 0

[State -1, Warp]
type = ChangeState
value = 60000
triggerall = var(21) >= 1
triggerall = ctrl
triggerall = time > 0
trigger1 = InguardDist
trigger2 = P2bodydist X > 130

;===========================================================================
;---------------------------------------------------------------------------

;Unkown4 level4
[State -1, Unknown4]
type = ChangeState
value = 2
triggerall = command = "Super Fire"
triggerall = power >= 4000
trigger1 = statetype != A
trigger1 = ctrl

;Unkown3 level2
[State -1, Unknown3]
type = ChangeState
value = 10021
triggerall = command = "Stars Burst"
triggerall = power >= 2000
trigger1 = statetype != A
trigger1 = ctrl

;Unkown2 level3
[State -1, Unknown2]
type = ChangeState
value = 10011
triggerall = command = "Falling Stars"
triggerall = power >= 3000
trigger1 = statetype != A
trigger1 = ctrl

;Unkown1 level2
[State -1, Unknown1]
type = ChangeState
value = 10000
triggerall = command = "Super Combination"
triggerall = power >= 2000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact
;---------------------------------------------------------------------------
;Smash Kung Fu Upper (uses one super bar)
;X}bVEJt[EEbp[iQ[WxPj
[State -1, Smash Kung Fu Upper]
type = ChangeState
value = 3050
triggerall = command = "SmashKFUpper"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3050,3100)
trigger2 = movecontact

;---------------------------------------------------------------------------
;Triple Kung Fu Palm (uses one super bar)
;OJt[˂iQ[WxPj
[State -1, Triple Kung Fu Palm]
type = ChangeState
value = 3000
triggerall = command = "TripleKFPalm"
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype != A
trigger2 = hitdefattr = SC, NA, SA, HA
trigger2 = stateno != [3000,3050)
trigger2 = movecontact

;===========================================================================
;This is not a move, but it sets up var(1) to be 1 if conditions are right
;for a combo into a special move (used below).
;Since a lot of special moves rely on the same conditions, this reduces
;redundant logic.
[State -1, Combo condition Reset]
type = VarSet
trigger1 = 1
var(1) = 0

[State -1, Combo condition Check]
type = VarSet
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = [200,299]) || (stateno = [400,499])
trigger2 = stateno != 440 ;Except for sweep kick
trigger2 = movecontact
var(1) = 1

[State -1, Unknown2]
type = ChangeState
value = 60021
triggerall = command = "Star Canon"
triggerall = numhelper(3) <= 0
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Fast Kung Fu Knee]
type = ChangeState
value = 60011
triggerall = command = "Star Bomb"
triggerall = numhelper(2) <= 0
trigger1 = Statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Fast Kung Fu Knee (1/3 super bar)
;Jt[RiQ[WxP^Rj
[State -1, Fast Kung Fu Knee]
type = ChangeState
value = 1070
triggerall = command = "FF_ab"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Knee
;Jt[Rij
[State -1, Light Kung Fu Knee]
type = ChangeState
value = 1050
triggerall = command = "FF_a"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Knee
;Jt[Rij
[State -1, Strong Kung Fu Knee]
type = ChangeState
value = 1060
triggerall = command = "FF_b"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Palm (1/3 super bar)
;Jt[˂iQ[WxP^Rj
[State -1, Fast Kung Fu Palm]
type = ChangeState
value = 1020
triggerall = command = "QCF_xy"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Palm
;Jt[˂ij
[State -1, Light Kung Fu Palm]
type = ChangeState
value = 1000
triggerall = command = "QCF_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Palm
;Jt[˂ij
[State -1, Strong Kung Fu Palm]
type = ChangeState
value = 1010
triggerall = command = "QCF_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Upper (1/3 super bar)
;Jt[EEbp[
[State -1, Fast Kung Fu Upper]
type = ChangeState
value = 1120
triggerall = command = "upper_xy"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Upper
;Jt[EEbp[ij
[State -1, Light Kung Fu Upper]
type = ChangeState
value = 1100
triggerall = command = "upper_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Upper
;Jt[EEbp[ij
[State -1, Strong Kung Fu Upper]
type = ChangeState
value = 1110
triggerall = command = "upper_y"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Fast Kung Fu Blow (1/3 super bar)
[State -1, Fast Kung Fu Blow]
type = ChangeState
value = 1220
triggerall = command = "QCB_xy"
triggerall = power >= 330
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Light Kung Fu Blow
[State -1, Light Kung Fu Blow]
type = ChangeState
value = 1200
triggerall = command = "QCB_x"
trigger1 = var(1) ;Use combo condition (above)

;---------------------------------------------------------------------------
;Strong Kung Fu Blow
[State -1, Strong Kung Fu Blow]
type = ChangeState
value = 1210
triggerall = command = "QCB_y"
trigger1 = var(1) ;Use combo condition (above)

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Kung Fu Throw
;
[State -1, Kung Fu Throw]
type = ChangeState
value = 800
triggerall = command = "y"
triggerall = statetype = S
triggerall = ctrl
triggerall = stateno != 100
trigger1 = command = "holdfwd"
trigger1 = p2bodydist X < 3
trigger1 = (p2statetype = S) || (p2statetype = C)
trigger1 = p2movetype != H
trigger2 = command = "holdback"
trigger2 = p2bodydist X < 5
trigger2 = (p2statetype = S) || (p2statetype = C)
trigger2 = p2movetype != H

[State -1, Warp]
type = ChangeState
value = 60000
triggerall = command = "Warp"
trigger1 = ctrl

[State -1, Warp]
type = ChangeState
value = 60000
triggerall = command = "Warp"
trigger1 = palno = 6
trigger2 = palno = 12

;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 200
trigger2 = time > 6

;---------------------------------------------------------------------------
;Stand Strong Punch
;p`
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Stand Light Kick
;LbN
[State -1, Stand Light Kick]
type = ChangeState
value = 230
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 7
trigger3 = (stateno = 230) && time > 9

;---------------------------------------------------------------------------
;Standing Strong Kick
;LbN
[State -1, Standing Strong Kick]
type = ChangeState
value = 240
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200) && time > 5
trigger3 = (stateno = 230) && time > 6

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Light Punch
;Ⴊݎp`
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Crouching Strong Punch
;Ⴊ݋p`
[State -1, Crouching Strong Punch]
type = ChangeState
value = 410
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Light Kick
;ႪݎLbN
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Crouching Strong Kick
;Ⴊ݋LbN
[State -1, Crouching Strong Kick]
type = ChangeState
value = 440
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 400) || (stateno = 430)
trigger2 = (time > 9) || (movecontact && time > 5)

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎p`
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = statetime >= 7
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Punch
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 1350 ;Air blocking

;---------------------------------------------------------------------------
;Jump Strong Kick
;󒆋LbN
[State -1, Jump Strong Kick]
type = ChangeState
value = 640
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600 || stateno = 630 ;jump_x or jump_a
trigger2 = movecontact
trigger3 = stateno = 1350 ;Air blocking
